@@ -3,8 +3,8 @@
 ### Unprepared (avoid working on `similar(x)`)
 
 function DI.value_and_pushforward(
-    f::F, backend::AutoForwardDiff, x, tx::NTuple{B}, contexts::Vararg{DI.Context,C}
-) where {F,B,C}
+        f::F, backend::AutoForwardDiff, x, tx::NTuple{B}, contexts::Vararg{DI.Context, C}
+    ) where {F, B, C}
     T = tag_type(f, backend, x)
     xdual = make_dual(T, x, tx)
     contexts_dual = translate(eltype(xdual), contexts)
@@ -15,13 +15,13 @@ function DI.value_and_pushforward(
 end
 
 function DI.value_and_pushforward!(
-    f::F,
-    ty::NTuple{B},
-    backend::AutoForwardDiff,
-    x,
-    tx::NTuple{B},
-    contexts::Vararg{DI.Context,C},
-) where {F,B,C}
+        f::F,
+        ty::NTuple{B},
+        backend::AutoForwardDiff,
+        x,
+        tx::NTuple{B},
+        contexts::Vararg{DI.Context, C},
+    ) where {F, B, C}
     T = tag_type(f, backend, x)
     xdual = make_dual(T, x, tx)
     contexts_dual = translate(eltype(xdual), contexts)
@@ -32,8 +32,8 @@ function DI.value_and_pushforward!(
 end
 
 function DI.pushforward(
-    f::F, backend::AutoForwardDiff, x, tx::NTuple{B}, contexts::Vararg{DI.Context,C}
-) where {F,B,C}
+        f::F, backend::AutoForwardDiff, x, tx::NTuple{B}, contexts::Vararg{DI.Context, C}
+    ) where {F, B, C}
     T = tag_type(f, backend, x)
     xdual = make_dual(T, x, tx)
     contexts_dual = translate(eltype(xdual), contexts)
@@ -43,13 +43,13 @@ function DI.pushforward(
 end
 
 function DI.pushforward!(
-    f::F,
-    ty::NTuple{B},
-    backend::AutoForwardDiff,
-    x,
-    tx::NTuple{B},
-    contexts::Vararg{DI.Context,C},
-) where {F,B,C}
+        f::F,
+        ty::NTuple{B},
+        backend::AutoForwardDiff,
+        x,
+        tx::NTuple{B},
+        contexts::Vararg{DI.Context, C},
+    ) where {F, B, C}
     T = tag_type(f, backend, x)
     xdual = make_dual(T, x, tx)
     contexts_dual = translate(eltype(xdual), contexts)
@@ -60,7 +60,7 @@ end
 
 ### Prepared
 
-struct ForwardDiffOneArgPushforwardPrep{SIG,T,X,CD} <: DI.PushforwardPrep{SIG}
+struct ForwardDiffOneArgPushforwardPrep{SIG, T, X, CD} <: DI.PushforwardPrep{SIG}
     _sig::Val{SIG}
     _t::Type{T}
     xdual_tmp::X
@@ -68,13 +68,13 @@ struct ForwardDiffOneArgPushforwardPrep{SIG,T,X,CD} <: DI.PushforwardPrep{SIG}
 end
 
 function DI.prepare_pushforward_nokwarg(
-    strict::Val,
-    f::F,
-    backend::AutoForwardDiff,
-    x,
-    tx::NTuple{B},
-    contexts::Vararg{DI.Context,C};
-) where {F,B,C}
+        strict::Val,
+        f::F,
+        backend::AutoForwardDiff,
+        x,
+        tx::NTuple{B},
+        contexts::Vararg{DI.Context, C}
+    ) where {F, B, C}
     _sig = DI.signature(f, backend, x, tx, contexts...; strict)
     T = tag_type(f, backend, x)
     if DI.ismutable_array(x)
@@ -82,17 +82,17 @@ function DI.prepare_pushforward_nokwarg(
     else
         xdual_tmp = nothing
     end
-    contexts_dual = translate_toprep(Dual{T,eltype(x),B}, contexts)
+    contexts_dual = translate_toprep(Dual{T, eltype(x), B}, contexts)
     return ForwardDiffOneArgPushforwardPrep(_sig, T, xdual_tmp, contexts_dual)
 end
 
 function compute_ydual_onearg(
-    f::F,
-    prep::ForwardDiffOneArgPushforwardPrep{SIG,T},
-    x::Number,
-    tx::NTuple{B},
-    contexts::Vararg{DI.Context,C},
-) where {F,SIG,T,B,C}
+        f::F,
+        prep::ForwardDiffOneArgPushforwardPrep{SIG, T},
+        x::Number,
+        tx::NTuple{B},
+        contexts::Vararg{DI.Context, C},
+    ) where {F, SIG, T, B, C}
     xdual = make_dual(T, x, tx)
     contexts_dual = translate_prepared(contexts, prep.contexts_dual)
     ydual = f(xdual, contexts_dual...)
@@ -100,12 +100,12 @@ function compute_ydual_onearg(
 end
 
 function compute_ydual_onearg(
-    f::F,
-    prep::ForwardDiffOneArgPushforwardPrep{SIG,T},
-    x,
-    tx::NTuple{B},
-    contexts::Vararg{DI.Context,C},
-) where {F,SIG,T,B,C}
+        f::F,
+        prep::ForwardDiffOneArgPushforwardPrep{SIG, T},
+        x,
+        tx::NTuple{B},
+        contexts::Vararg{DI.Context, C},
+    ) where {F, SIG, T, B, C}
     if DI.ismutable_array(x)
         make_dual!(T, prep.xdual_tmp, x, tx)
         xdual_tmp = prep.xdual_tmp
@@ -118,13 +118,13 @@ function compute_ydual_onearg(
 end
 
 function DI.value_and_pushforward(
-    f::F,
-    prep::ForwardDiffOneArgPushforwardPrep{SIG,T},
-    backend::AutoForwardDiff,
-    x,
-    tx::NTuple{B},
-    contexts::Vararg{DI.Context,C},
-) where {F,SIG,T,B,C}
+        f::F,
+        prep::ForwardDiffOneArgPushforwardPrep{SIG, T},
+        backend::AutoForwardDiff,
+        x,
+        tx::NTuple{B},
+        contexts::Vararg{DI.Context, C},
+    ) where {F, SIG, T, B, C}
     DI.check_prep(f, prep, backend, x, tx, contexts...)
     ydual = compute_ydual_onearg(f, prep, x, tx, contexts...)
     y = myvalue(T, ydual)
@@ -133,14 +133,14 @@ function DI.value_and_pushforward(
 end
 
 function DI.value_and_pushforward!(
-    f::F,
-    ty::NTuple,
-    prep::ForwardDiffOneArgPushforwardPrep{SIG,T},
-    backend::AutoForwardDiff,
-    x,
-    tx::NTuple,
-    contexts::Vararg{DI.Context,C},
-) where {F,SIG,T,C}
+        f::F,
+        ty::NTuple,
+        prep::ForwardDiffOneArgPushforwardPrep{SIG, T},
+        backend::AutoForwardDiff,
+        x,
+        tx::NTuple,
+        contexts::Vararg{DI.Context, C},
+    ) where {F, SIG, T, C}
     DI.check_prep(f, prep, backend, x, tx, contexts...)
     ydual = compute_ydual_onearg(f, prep, x, tx, contexts...)
     y = myvalue(T, ydual)
@@ -149,13 +149,13 @@ function DI.value_and_pushforward!(
 end
 
 function DI.pushforward(
-    f::F,
-    prep::ForwardDiffOneArgPushforwardPrep{SIG,T},
-    backend::AutoForwardDiff,
-    x,
-    tx::NTuple{B},
-    contexts::Vararg{DI.Context,C},
-) where {F,SIG,T,B,C}
+        f::F,
+        prep::ForwardDiffOneArgPushforwardPrep{SIG, T},
+        backend::AutoForwardDiff,
+        x,
+        tx::NTuple{B},
+        contexts::Vararg{DI.Context, C},
+    ) where {F, SIG, T, B, C}
     DI.check_prep(f, prep, backend, x, tx, contexts...)
     ydual = compute_ydual_onearg(f, prep, x, tx, contexts...)
     ty = mypartials(T, Val(B), ydual)
@@ -163,14 +163,14 @@ function DI.pushforward(
 end
 
 function DI.pushforward!(
-    f::F,
-    ty::NTuple,
-    prep::ForwardDiffOneArgPushforwardPrep{SIG,T},
-    backend::AutoForwardDiff,
-    x,
-    tx::NTuple,
-    contexts::Vararg{DI.Context,C},
-) where {F,SIG,T,C}
+        f::F,
+        ty::NTuple,
+        prep::ForwardDiffOneArgPushforwardPrep{SIG, T},
+        backend::AutoForwardDiff,
+        x,
+        tx::NTuple,
+        contexts::Vararg{DI.Context, C},
+    ) where {F, SIG, T, C}
     DI.check_prep(f, prep, backend, x, tx, contexts...)
     ydual = compute_ydual_onearg(f, prep, x, tx, contexts...)
     mypartials!(T, ty, ydual)
@@ -179,7 +179,7 @@ end
 
 ## Derivative
 
-struct ForwardDiffOneArgDerivativePrep{SIG,E} <: DI.DerivativePrep{SIG}
+struct ForwardDiffOneArgDerivativePrep{SIG, E} <: DI.DerivativePrep{SIG}
     _sig::Val{SIG}
     pushforward_prep::E
 end
@@ -187,28 +187,28 @@ end
 ### Unprepared
 
 function DI.value_and_derivative(
-    f::F, backend::AutoForwardDiff, x, contexts::Vararg{DI.Context,C}
-) where {F,C}
+        f::F, backend::AutoForwardDiff, x, contexts::Vararg{DI.Context, C}
+    ) where {F, C}
     y, ty = DI.value_and_pushforward(f, backend, x, (oneunit(x),), contexts...)
     return y, only(ty)
 end
 
 function DI.value_and_derivative!(
-    f::F, der, backend::AutoForwardDiff, x, contexts::Vararg{DI.Context,C}
-) where {F,C}
+        f::F, der, backend::AutoForwardDiff, x, contexts::Vararg{DI.Context, C}
+    ) where {F, C}
     y, _ = DI.value_and_pushforward!(f, (der,), backend, x, (oneunit(x),), contexts...)
     return y, der
 end
 
 function DI.derivative(
-    f::F, backend::AutoForwardDiff, x, contexts::Vararg{DI.Context,C}
-) where {F,C}
+        f::F, backend::AutoForwardDiff, x, contexts::Vararg{DI.Context, C}
+    ) where {F, C}
     return only(DI.pushforward(f, backend, x, (oneunit(x),), contexts...))
 end
 
 function DI.derivative!(
-    f::F, der, backend::AutoForwardDiff, x, contexts::Vararg{DI.Context,C}
-) where {F,C}
+        f::F, der, backend::AutoForwardDiff, x, contexts::Vararg{DI.Context, C}
+    ) where {F, C}
     DI.pushforward!(f, (der,), backend, x, (oneunit(x),), contexts...)
     return der
 end
@@ -216,8 +216,8 @@ end
 ### Prepared
 
 function DI.prepare_derivative_nokwarg(
-    strict::Val, f::F, backend::AutoForwardDiff, x, contexts::Vararg{DI.Context,C};
-) where {F,C}
+        strict::Val, f::F, backend::AutoForwardDiff, x, contexts::Vararg{DI.Context, C}
+    ) where {F, C}
     _sig = DI.signature(f, backend, x, contexts...; strict)
     pushforward_prep = DI.prepare_pushforward_nokwarg(
         strict, f, backend, x, (oneunit(x),), contexts...
@@ -226,12 +226,12 @@ function DI.prepare_derivative_nokwarg(
 end
 
 function DI.value_and_derivative(
-    f::F,
-    prep::ForwardDiffOneArgDerivativePrep,
-    backend::AutoForwardDiff,
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {F,C}
+        f::F,
+        prep::ForwardDiffOneArgDerivativePrep,
+        backend::AutoForwardDiff,
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {F, C}
     DI.check_prep(f, prep, backend, x, contexts...)
     y, ty = DI.value_and_pushforward(
         f, prep.pushforward_prep, backend, x, (oneunit(x),), contexts...
@@ -240,13 +240,13 @@ function DI.value_and_derivative(
 end
 
 function DI.value_and_derivative!(
-    f::F,
-    der,
-    prep::ForwardDiffOneArgDerivativePrep,
-    backend::AutoForwardDiff,
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {F,C}
+        f::F,
+        der,
+        prep::ForwardDiffOneArgDerivativePrep,
+        backend::AutoForwardDiff,
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {F, C}
     DI.check_prep(f, prep, backend, x, contexts...)
     y, _ = DI.value_and_pushforward!(
         f, (der,), prep.pushforward_prep, backend, x, (oneunit(x),), contexts...
@@ -255,12 +255,12 @@ function DI.value_and_derivative!(
 end
 
 function DI.derivative(
-    f::F,
-    prep::ForwardDiffOneArgDerivativePrep,
-    backend::AutoForwardDiff,
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {F,C}
+        f::F,
+        prep::ForwardDiffOneArgDerivativePrep,
+        backend::AutoForwardDiff,
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {F, C}
     DI.check_prep(f, prep, backend, x, contexts...)
     return only(
         DI.pushforward(f, prep.pushforward_prep, backend, x, (oneunit(x),), contexts...)
@@ -268,13 +268,13 @@ function DI.derivative(
 end
 
 function DI.derivative!(
-    f::F,
-    der,
-    prep::ForwardDiffOneArgDerivativePrep,
-    backend::AutoForwardDiff,
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {F,C}
+        f::F,
+        der,
+        prep::ForwardDiffOneArgDerivativePrep,
+        backend::AutoForwardDiff,
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {F, C}
     DI.check_prep(f, prep, backend, x, contexts...)
     DI.pushforward!(
         f, (der,), prep.pushforward_prep, backend, x, (oneunit(x),), contexts...
@@ -287,13 +287,13 @@ end
 ### Unprepared, only when chunk size and tag are not specified
 
 function DI.value_and_gradient!(
-    f::F, grad, backend::AutoForwardDiff{chunksize,T}, x, contexts::Vararg{DI.Context,C}
-) where {F,C,chunksize,T}
+        f::F, grad, backend::AutoForwardDiff{chunksize, T}, x, contexts::Vararg{DI.Context, C}
+    ) where {F, C, chunksize, T}
     if (
-        isnothing(chunksize) &&
-        T === Nothing &&
-        contexts isa NTuple{C,DI.GeneralizedConstant}
-    )
+            isnothing(chunksize) &&
+                T === Nothing &&
+                contexts isa NTuple{C, DI.GeneralizedConstant}
+        )
         fc = DI.fix_tail(f, map(DI.unwrap, contexts)...)
         result = DiffResult(zero(eltype(x)), (grad,))
         result = gradient!(result, fc, x)
@@ -307,13 +307,13 @@ function DI.value_and_gradient!(
 end
 
 function DI.value_and_gradient(
-    f::F, backend::AutoForwardDiff{chunksize,T}, x, contexts::Vararg{DI.Context,C}
-) where {F,C,chunksize,T}
+        f::F, backend::AutoForwardDiff{chunksize, T}, x, contexts::Vararg{DI.Context, C}
+    ) where {F, C, chunksize, T}
     if (
-        isnothing(chunksize) &&
-        T === Nothing &&
-        contexts isa NTuple{C,DI.GeneralizedConstant}
-    )
+            isnothing(chunksize) &&
+                T === Nothing &&
+                contexts isa NTuple{C, DI.GeneralizedConstant}
+        )
         fc = DI.fix_tail(f, map(DI.unwrap, contexts)...)
         result = GradientResult(x)
         result = gradient!(result, fc, x)
@@ -325,13 +325,13 @@ function DI.value_and_gradient(
 end
 
 function DI.gradient!(
-    f::F, grad, backend::AutoForwardDiff{chunksize,T}, x, contexts::Vararg{DI.Context,C}
-) where {F,C,chunksize,T}
+        f::F, grad, backend::AutoForwardDiff{chunksize, T}, x, contexts::Vararg{DI.Context, C}
+    ) where {F, C, chunksize, T}
     if (
-        isnothing(chunksize) &&
-        T === Nothing &&
-        contexts isa NTuple{C,DI.GeneralizedConstant}
-    )
+            isnothing(chunksize) &&
+                T === Nothing &&
+                contexts isa NTuple{C, DI.GeneralizedConstant}
+        )
         fc = DI.fix_tail(f, map(DI.unwrap, contexts)...)
         return gradient!(grad, fc, x)
     else
@@ -341,13 +341,13 @@ function DI.gradient!(
 end
 
 function DI.gradient(
-    f::F, backend::AutoForwardDiff{chunksize,T}, x, contexts::Vararg{DI.Context,C}
-) where {F,C,chunksize,T}
+        f::F, backend::AutoForwardDiff{chunksize, T}, x, contexts::Vararg{DI.Context, C}
+    ) where {F, C, chunksize, T}
     if (
-        isnothing(chunksize) &&
-        T === Nothing &&
-        contexts isa NTuple{C,DI.GeneralizedConstant}
-    )
+            isnothing(chunksize) &&
+                T === Nothing &&
+                contexts isa NTuple{C, DI.GeneralizedConstant}
+        )
         fc = DI.fix_tail(f, map(DI.unwrap, contexts)...)
         return gradient(fc, x)
     else
@@ -358,19 +358,19 @@ end
 
 ### Prepared
 
-struct ForwardDiffGradientPrep{SIG,C,CD} <: DI.GradientPrep{SIG}
+struct ForwardDiffGradientPrep{SIG, C, CD} <: DI.GradientPrep{SIG}
     _sig::Val{SIG}
     config::C
     contexts_dual::CD
 end
 
 function DI.prepare_gradient_nokwarg(
-    strict::Val,
-    f::F,
-    backend::AutoForwardDiff,
-    x::AbstractArray,
-    contexts::Vararg{DI.Context,C};
-) where {F,C}
+        strict::Val,
+        f::F,
+        backend::AutoForwardDiff,
+        x::AbstractArray,
+        contexts::Vararg{DI.Context, C}
+    ) where {F, C}
     _sig = DI.signature(f, backend, x, contexts...; strict)
     chunk = choose_chunk(backend, x)
     tag = get_tag(f, backend, x)
@@ -380,13 +380,13 @@ function DI.prepare_gradient_nokwarg(
 end
 
 function DI.value_and_gradient!(
-    f::F,
-    grad,
-    prep::ForwardDiffGradientPrep,
-    backend::AutoForwardDiff,
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {F,C}
+        f::F,
+        grad,
+        prep::ForwardDiffGradientPrep,
+        backend::AutoForwardDiff,
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {F, C}
     DI.check_prep(f, prep, backend, x, contexts...)
     contexts_dual = translate_prepared(contexts, prep.contexts_dual)
     fc = DI.fix_tail(f, contexts_dual...)
@@ -402,12 +402,12 @@ function DI.value_and_gradient!(
 end
 
 function DI.value_and_gradient(
-    f::F,
-    prep::ForwardDiffGradientPrep,
-    backend::AutoForwardDiff,
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {F,C}
+        f::F,
+        prep::ForwardDiffGradientPrep,
+        backend::AutoForwardDiff,
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {F, C}
     DI.check_prep(f, prep, backend, x, contexts...)
     contexts_dual = translate_prepared(contexts, prep.contexts_dual)
     fc = DI.fix_tail(f, contexts_dual...)
@@ -421,13 +421,13 @@ function DI.value_and_gradient(
 end
 
 function DI.gradient!(
-    f::F,
-    grad,
-    prep::ForwardDiffGradientPrep,
-    backend::AutoForwardDiff,
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {F,C}
+        f::F,
+        grad,
+        prep::ForwardDiffGradientPrep,
+        backend::AutoForwardDiff,
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {F, C}
     DI.check_prep(f, prep, backend, x, contexts...)
     contexts_dual = translate_prepared(contexts, prep.contexts_dual)
     fc = DI.fix_tail(f, contexts_dual...)
@@ -439,12 +439,12 @@ function DI.gradient!(
 end
 
 function DI.gradient(
-    f::F,
-    prep::ForwardDiffGradientPrep,
-    backend::AutoForwardDiff,
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {F,C}
+        f::F,
+        prep::ForwardDiffGradientPrep,
+        backend::AutoForwardDiff,
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {F, C}
     DI.check_prep(f, prep, backend, x, contexts...)
     contexts_dual = translate_prepared(contexts, prep.contexts_dual)
     fc = DI.fix_tail(f, contexts_dual...)
@@ -460,13 +460,13 @@ end
 ### Unprepared, only when chunk size and tag are not specified
 
 function DI.value_and_jacobian!(
-    f::F, jac, backend::AutoForwardDiff{chunksize,T}, x, contexts::Vararg{DI.Context,C}
-) where {F,C,chunksize,T}
+        f::F, jac, backend::AutoForwardDiff{chunksize, T}, x, contexts::Vararg{DI.Context, C}
+    ) where {F, C, chunksize, T}
     if (
-        isnothing(chunksize) &&
-        T === Nothing &&
-        contexts isa NTuple{C,DI.GeneralizedConstant}
-    )
+            isnothing(chunksize) &&
+                T === Nothing &&
+                contexts isa NTuple{C, DI.GeneralizedConstant}
+        )
         fc = DI.fix_tail(f, map(DI.unwrap, contexts)...)
         y = fc(x)
         result = DiffResult(y, (jac,))
@@ -481,13 +481,13 @@ function DI.value_and_jacobian!(
 end
 
 function DI.value_and_jacobian(
-    f::F, backend::AutoForwardDiff{chunksize,T}, x, contexts::Vararg{DI.Context,C}
-) where {F,C,chunksize,T}
+        f::F, backend::AutoForwardDiff{chunksize, T}, x, contexts::Vararg{DI.Context, C}
+    ) where {F, C, chunksize, T}
     if (
-        isnothing(chunksize) &&
-        T === Nothing &&
-        contexts isa NTuple{C,DI.GeneralizedConstant}
-    )
+            isnothing(chunksize) &&
+                T === Nothing &&
+                contexts isa NTuple{C, DI.GeneralizedConstant}
+        )
         fc = DI.fix_tail(f, map(DI.unwrap, contexts)...)
         return fc(x), jacobian(fc, x)
     else
@@ -497,13 +497,13 @@ function DI.value_and_jacobian(
 end
 
 function DI.jacobian!(
-    f::F, jac, backend::AutoForwardDiff{chunksize,T}, x, contexts::Vararg{DI.Context,C}
-) where {F,C,chunksize,T}
+        f::F, jac, backend::AutoForwardDiff{chunksize, T}, x, contexts::Vararg{DI.Context, C}
+    ) where {F, C, chunksize, T}
     if (
-        isnothing(chunksize) &&
-        T === Nothing &&
-        contexts isa NTuple{C,DI.GeneralizedConstant}
-    )
+            isnothing(chunksize) &&
+                T === Nothing &&
+                contexts isa NTuple{C, DI.GeneralizedConstant}
+        )
         fc = DI.fix_tail(f, map(DI.unwrap, contexts)...)
         return jacobian!(jac, fc, x)
     else
@@ -513,13 +513,13 @@ function DI.jacobian!(
 end
 
 function DI.jacobian(
-    f::F, backend::AutoForwardDiff{chunksize,T}, x, contexts::Vararg{DI.Context,C}
-) where {F,C,chunksize,T}
+        f::F, backend::AutoForwardDiff{chunksize, T}, x, contexts::Vararg{DI.Context, C}
+    ) where {F, C, chunksize, T}
     if (
-        isnothing(chunksize) &&
-        T === Nothing &&
-        contexts isa NTuple{C,DI.GeneralizedConstant}
-    )
+            isnothing(chunksize) &&
+                T === Nothing &&
+                contexts isa NTuple{C, DI.GeneralizedConstant}
+        )
         fc = DI.fix_tail(f, map(DI.unwrap, contexts)...)
         return jacobian(fc, x)
     else
@@ -530,15 +530,15 @@ end
 
 ### Prepared
 
-struct ForwardDiffOneArgJacobianPrep{SIG,C,CD} <: DI.JacobianPrep{SIG}
+struct ForwardDiffOneArgJacobianPrep{SIG, C, CD} <: DI.JacobianPrep{SIG}
     _sig::Val{SIG}
     config::C
     contexts_dual::CD
 end
 
 function DI.prepare_jacobian_nokwarg(
-    strict::Val, f::F, backend::AutoForwardDiff, x, contexts::Vararg{DI.Context,C};
-) where {F,C}
+        strict::Val, f::F, backend::AutoForwardDiff, x, contexts::Vararg{DI.Context, C}
+    ) where {F, C}
     _sig = DI.signature(f, backend, x, contexts...; strict)
     chunk = choose_chunk(backend, x)
     tag = get_tag(f, backend, x)
@@ -548,13 +548,13 @@ function DI.prepare_jacobian_nokwarg(
 end
 
 function DI.value_and_jacobian!(
-    f::F,
-    jac,
-    prep::ForwardDiffOneArgJacobianPrep,
-    backend::AutoForwardDiff,
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {F,C}
+        f::F,
+        jac,
+        prep::ForwardDiffOneArgJacobianPrep,
+        backend::AutoForwardDiff,
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {F, C}
     DI.check_prep(f, prep, backend, x, contexts...)
     contexts_dual = translate_prepared(contexts, prep.contexts_dual)
     fc = DI.fix_tail(f, contexts_dual...)
@@ -571,12 +571,12 @@ function DI.value_and_jacobian!(
 end
 
 function DI.value_and_jacobian(
-    f::F,
-    prep::ForwardDiffOneArgJacobianPrep,
-    backend::AutoForwardDiff,
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {F,C}
+        f::F,
+        prep::ForwardDiffOneArgJacobianPrep,
+        backend::AutoForwardDiff,
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {F, C}
     DI.check_prep(f, prep, backend, x, contexts...)
     contexts_dual = translate_prepared(contexts, prep.contexts_dual)
     fc = DI.fix_tail(f, contexts_dual...)
@@ -588,13 +588,13 @@ function DI.value_and_jacobian(
 end
 
 function DI.jacobian!(
-    f::F,
-    jac,
-    prep::ForwardDiffOneArgJacobianPrep,
-    backend::AutoForwardDiff,
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {F,C}
+        f::F,
+        jac,
+        prep::ForwardDiffOneArgJacobianPrep,
+        backend::AutoForwardDiff,
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {F, C}
     DI.check_prep(f, prep, backend, x, contexts...)
     contexts_dual = translate_prepared(contexts, prep.contexts_dual)
     fc = DI.fix_tail(f, contexts_dual...)
@@ -606,12 +606,12 @@ function DI.jacobian!(
 end
 
 function DI.jacobian(
-    f::F,
-    prep::ForwardDiffOneArgJacobianPrep,
-    backend::AutoForwardDiff,
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {F,C}
+        f::F,
+        prep::ForwardDiffOneArgJacobianPrep,
+        backend::AutoForwardDiff,
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {F, C}
     DI.check_prep(f, prep, backend, x, contexts...)
     contexts_dual = translate_prepared(contexts, prep.contexts_dual)
     fc = DI.fix_tail(f, contexts_dual...)
@@ -625,19 +625,19 @@ end
 ## Second derivative
 
 function DI.prepare_second_derivative_nokwarg(
-    strict::Val, f::F, backend::AutoForwardDiff, x, contexts::Vararg{DI.Context,C};
-) where {F,C}
+        strict::Val, f::F, backend::AutoForwardDiff, x, contexts::Vararg{DI.Context, C}
+    ) where {F, C}
     _sig = DI.signature(f, backend, x, contexts...; strict)
     return DI.NoSecondDerivativePrep(_sig)
 end
 
 function DI.second_derivative(
-    f::F,
-    prep::DI.NoSecondDerivativePrep,
-    backend::AutoForwardDiff,
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {F,C}
+        f::F,
+        prep::DI.NoSecondDerivativePrep,
+        backend::AutoForwardDiff,
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {F, C}
     DI.check_prep(f, prep, backend, x, contexts...)
     T = tag_type(f, backend, x)
     xdual = make_dual(T, x, oneunit(x))
@@ -649,13 +649,13 @@ function DI.second_derivative(
 end
 
 function DI.second_derivative!(
-    f::F,
-    der2,
-    prep::DI.NoSecondDerivativePrep,
-    backend::AutoForwardDiff,
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {F,C}
+        f::F,
+        der2,
+        prep::DI.NoSecondDerivativePrep,
+        backend::AutoForwardDiff,
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {F, C}
     DI.check_prep(f, prep, backend, x, contexts...)
     T = tag_type(f, backend, x)
     xdual = make_dual(T, x, oneunit(x))
@@ -667,12 +667,12 @@ function DI.second_derivative!(
 end
 
 function DI.value_derivative_and_second_derivative(
-    f::F,
-    prep::DI.NoSecondDerivativePrep,
-    backend::AutoForwardDiff,
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {F,C}
+        f::F,
+        prep::DI.NoSecondDerivativePrep,
+        backend::AutoForwardDiff,
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {F, C}
     DI.check_prep(f, prep, backend, x, contexts...)
     T = tag_type(f, backend, x)
     xdual = make_dual(T, x, oneunit(x))
@@ -687,14 +687,14 @@ function DI.value_derivative_and_second_derivative(
 end
 
 function DI.value_derivative_and_second_derivative!(
-    f::F,
-    der,
-    der2,
-    prep::DI.NoSecondDerivativePrep,
-    backend::AutoForwardDiff,
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {F,C}
+        f::F,
+        der,
+        der2,
+        prep::DI.NoSecondDerivativePrep,
+        backend::AutoForwardDiff,
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {F, C}
     DI.check_prep(f, prep, backend, x, contexts...)
     T = tag_type(f, backend, x)
     xdual = make_dual(T, x, oneunit(x))
@@ -713,13 +713,13 @@ end
 ### Unprepared, only when chunk size and tag are not specified
 
 function DI.hessian!(
-    f::F, hess, backend::AutoForwardDiff{chunksize,T}, x, contexts::Vararg{DI.Context,C}
-) where {F,C,chunksize,T}
+        f::F, hess, backend::AutoForwardDiff{chunksize, T}, x, contexts::Vararg{DI.Context, C}
+    ) where {F, C, chunksize, T}
     if (
-        isnothing(chunksize) &&
-        T === Nothing &&
-        contexts isa NTuple{C,DI.GeneralizedConstant}
-    )
+            isnothing(chunksize) &&
+                T === Nothing &&
+                contexts isa NTuple{C, DI.GeneralizedConstant}
+        )
         fc = DI.fix_tail(f, map(DI.unwrap, contexts)...)
         return hessian!(hess, fc, x)
     else
@@ -729,13 +729,13 @@ function DI.hessian!(
 end
 
 function DI.hessian(
-    f::F, backend::AutoForwardDiff{chunksize,T}, x, contexts::Vararg{DI.Context,C}
-) where {F,C,chunksize,T}
+        f::F, backend::AutoForwardDiff{chunksize, T}, x, contexts::Vararg{DI.Context, C}
+    ) where {F, C, chunksize, T}
     if (
-        isnothing(chunksize) &&
-        T === Nothing &&
-        contexts isa NTuple{C,DI.GeneralizedConstant}
-    )
+            isnothing(chunksize) &&
+                T === Nothing &&
+                contexts isa NTuple{C, DI.GeneralizedConstant}
+        )
         fc = DI.fix_tail(f, map(DI.unwrap, contexts)...)
         return hessian(fc, x)
     else
@@ -745,18 +745,18 @@ function DI.hessian(
 end
 
 function DI.value_gradient_and_hessian!(
-    f::F,
-    grad,
-    hess,
-    backend::AutoForwardDiff{chunksize,T},
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {F,C,chunksize,T}
+        f::F,
+        grad,
+        hess,
+        backend::AutoForwardDiff{chunksize, T},
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {F, C, chunksize, T}
     if (
-        isnothing(chunksize) &&
-        T === Nothing &&
-        contexts isa NTuple{C,DI.GeneralizedConstant}
-    )
+            isnothing(chunksize) &&
+                T === Nothing &&
+                contexts isa NTuple{C, DI.GeneralizedConstant}
+        )
         fc = DI.fix_tail(f, map(DI.unwrap, contexts)...)
         result = DiffResult(oneunit(eltype(x)), (grad, hess))
         result = hessian!(result, fc, x)
@@ -771,13 +771,13 @@ function DI.value_gradient_and_hessian!(
 end
 
 function DI.value_gradient_and_hessian(
-    f::F, backend::AutoForwardDiff{chunksize,T}, x, contexts::Vararg{DI.Context,C}
-) where {F,C,chunksize,T}
+        f::F, backend::AutoForwardDiff{chunksize, T}, x, contexts::Vararg{DI.Context, C}
+    ) where {F, C, chunksize, T}
     if (
-        isnothing(chunksize) &&
-        T === Nothing &&
-        contexts isa NTuple{C,DI.GeneralizedConstant}
-    )
+            isnothing(chunksize) &&
+                T === Nothing &&
+                contexts isa NTuple{C, DI.GeneralizedConstant}
+        )
         fc = DI.fix_tail(f, map(DI.unwrap, contexts)...)
         result = HessianResult(x)
         result = hessian!(result, fc, x)
@@ -790,7 +790,7 @@ end
 
 ### Prepared
 
-struct ForwardDiffHessianPrep{SIG,C1,C2,CD} <: DI.HessianPrep{SIG}
+struct ForwardDiffHessianPrep{SIG, C1, C2, CD} <: DI.HessianPrep{SIG}
     _sig::Val{SIG}
     array_config::C1
     result_config::C2
@@ -798,8 +798,8 @@ struct ForwardDiffHessianPrep{SIG,C1,C2,CD} <: DI.HessianPrep{SIG}
 end
 
 function DI.prepare_hessian_nokwarg(
-    strict::Val, f::F, backend::AutoForwardDiff, x, contexts::Vararg{DI.Context,C};
-) where {F,C}
+        strict::Val, f::F, backend::AutoForwardDiff, x, contexts::Vararg{DI.Context, C}
+    ) where {F, C}
     _sig = DI.signature(f, backend, x, contexts...; strict)
     chunk = choose_chunk(backend, x)
     tag = get_tag(f, backend, x)
@@ -811,13 +811,13 @@ function DI.prepare_hessian_nokwarg(
 end
 
 function DI.hessian!(
-    f::F,
-    hess,
-    prep::ForwardDiffHessianPrep,
-    backend::AutoForwardDiff,
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {F,C}
+        f::F,
+        hess,
+        prep::ForwardDiffHessianPrep,
+        backend::AutoForwardDiff,
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {F, C}
     DI.check_prep(f, prep, backend, x, contexts...)
     contexts_dual = translate_prepared(contexts, prep.contexts_dual)
     fc = DI.fix_tail(f, contexts_dual...)
@@ -829,12 +829,12 @@ function DI.hessian!(
 end
 
 function DI.hessian(
-    f::F,
-    prep::ForwardDiffHessianPrep,
-    backend::AutoForwardDiff,
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {F,C}
+        f::F,
+        prep::ForwardDiffHessianPrep,
+        backend::AutoForwardDiff,
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {F, C}
     DI.check_prep(f, prep, backend, x, contexts...)
     contexts_dual = translate_prepared(contexts, prep.contexts_dual)
     fc = DI.fix_tail(f, contexts_dual...)
@@ -846,14 +846,14 @@ function DI.hessian(
 end
 
 function DI.value_gradient_and_hessian!(
-    f::F,
-    grad,
-    hess,
-    prep::ForwardDiffHessianPrep,
-    backend::AutoForwardDiff,
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {F,C}
+        f::F,
+        grad,
+        hess,
+        prep::ForwardDiffHessianPrep,
+        backend::AutoForwardDiff,
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {F, C}
     DI.check_prep(f, prep, backend, x, contexts...)
     contexts_dual = translate_prepared(contexts, prep.contexts_dual)
     fc = DI.fix_tail(f, contexts_dual...)
@@ -870,12 +870,12 @@ function DI.value_gradient_and_hessian!(
 end
 
 function DI.value_gradient_and_hessian(
-    f::F,
-    prep::ForwardDiffHessianPrep,
-    backend::AutoForwardDiff,
-    x,
-    contexts::Vararg{DI.Context,C},
-) where {F,C}
+        f::F,
+        prep::ForwardDiffHessianPrep,
+        backend::AutoForwardDiff,
+        x,
+        contexts::Vararg{DI.Context, C},
+    ) where {F, C}
     DI.check_prep(f, prep, backend, x, contexts...)
     contexts_dual = translate_prepared(contexts, prep.contexts_dual)
     fc = DI.fix_tail(f, contexts_dual...)
