@@ -2,19 +2,19 @@
 
 # Contains either a single pre-allocated initial TPS
 # or a vector of pre-allocated TPSs.
-struct GTPSAOneArgPushforwardPrep{SIG,X} <: DI.PushforwardPrep{SIG}
+struct GTPSAOneArgPushforwardPrep{SIG, X} <: DI.PushforwardPrep{SIG}
     _sig::Val{SIG}
     xt::X
 end
 
 function DI.prepare_pushforward_nokwarg(
-    strict::Val,
-    f::F,
-    backend::AutoGTPSA{D},
-    x,
-    tx::NTuple,
-    contexts::Vararg{DI.Constant,C};
-) where {F,D,C}
+        strict::Val,
+        f::F,
+        backend::AutoGTPSA{D},
+        x,
+        tx::NTuple,
+        contexts::Vararg{DI.Constant, C}
+    ) where {F, D, C}
     _sig = DI.signature(f, backend, x, tx, contexts...; strict)
     # For pushforward/JVP, we only actually need 1 single variable (in the GTPSA sense)
     # because we even if we did multiple we will add up the derivatives of each at the end.
@@ -24,29 +24,29 @@ function DI.prepare_pushforward_nokwarg(
         d = Descriptor(1, 1) # 1 variable to first order
     end
     if x isa Number
-        xt = TPS{promote_type(typeof(first(tx)), typeof(x), Float64)}(; use=d)
+        xt = TPS{promote_type(typeof(first(tx)), typeof(x), Float64)}(; use = d)
         return GTPSAOneArgPushforwardPrep(_sig, xt)
     else
         xt = similar(x, TPS{promote_type(eltype(first(tx)), eltype(x), Float64)})
         for i in eachindex(xt)
-            xt[i] = TPS{promote_type(eltype(first(tx)), eltype(x), Float64)}(; use=d)
+            xt[i] = TPS{promote_type(eltype(first(tx)), eltype(x), Float64)}(; use = d)
         end
         return GTPSAOneArgPushforwardPrep(_sig, xt)
     end
 end
 
 function DI.pushforward(
-    f,
-    prep::GTPSAOneArgPushforwardPrep,
-    backend::AutoGTPSA,
-    x,
-    tx::NTuple,
-    contexts::Vararg{DI.Constant,C},
-) where {C}
+        f,
+        prep::GTPSAOneArgPushforwardPrep,
+        backend::AutoGTPSA,
+        x,
+        tx::NTuple,
+        contexts::Vararg{DI.Constant, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, tx, contexts...)
     fc = DI.fix_tail(f, map(DI.unwrap, contexts)...)
     ty = map(tx) do dx
-        foreach((t, xi, dxi) -> (t[0]=xi; t[1]=dxi), prep.xt, x, dx)
+        foreach((t, xi, dxi) -> (t[0] = xi; t[1] = dxi), prep.xt, x, dx)
         yt = fc(prep.xt)
         if yt isa Number
             return yt[1]
@@ -59,19 +59,19 @@ function DI.pushforward(
 end
 
 function DI.pushforward!(
-    f,
-    ty::NTuple,
-    prep::GTPSAOneArgPushforwardPrep,
-    backend::AutoGTPSA,
-    x,
-    tx::NTuple,
-    contexts::Vararg{DI.Constant,C},
-) where {C}
+        f,
+        ty::NTuple,
+        prep::GTPSAOneArgPushforwardPrep,
+        backend::AutoGTPSA,
+        x,
+        tx::NTuple,
+        contexts::Vararg{DI.Constant, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, tx, contexts...)
     fc = DI.fix_tail(f, map(DI.unwrap, contexts)...)
     for b in eachindex(tx, ty)
         dx, dy = tx[b], ty[b]
-        foreach((t, xi, dxi) -> (t[0]=xi; t[1]=dxi), prep.xt, x, dx)
+        foreach((t, xi, dxi) -> (t[0] = xi; t[1] = dxi), prep.xt, x, dx)
         yt = fc(prep.xt)
         map!(t -> t[1], dy, yt)
     end
@@ -79,13 +79,13 @@ function DI.pushforward!(
 end
 
 function DI.value_and_pushforward(
-    f,
-    prep::GTPSAOneArgPushforwardPrep,
-    backend::AutoGTPSA,
-    x,
-    tx::NTuple,
-    contexts::Vararg{DI.Constant,C},
-) where {C}
+        f,
+        prep::GTPSAOneArgPushforwardPrep,
+        backend::AutoGTPSA,
+        x,
+        tx::NTuple,
+        contexts::Vararg{DI.Constant, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, tx, contexts...)
     ty = DI.pushforward(f, prep, backend, x, tx, contexts...)
     y = f(x, map(DI.unwrap, contexts)...)  # TODO: optimize
@@ -93,14 +93,14 @@ function DI.value_and_pushforward(
 end
 
 function DI.value_and_pushforward!(
-    f,
-    ty::NTuple,
-    prep::GTPSAOneArgPushforwardPrep,
-    backend::AutoGTPSA,
-    x,
-    tx::NTuple,
-    contexts::Vararg{DI.Constant,C},
-) where {C}
+        f,
+        ty::NTuple,
+        prep::GTPSAOneArgPushforwardPrep,
+        backend::AutoGTPSA,
+        x,
+        tx::NTuple,
+        contexts::Vararg{DI.Constant, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, tx, contexts...)
     DI.pushforward!(f, ty, prep, backend, x, tx, contexts...)
     y = f(x, map(DI.unwrap, contexts)...)  # TODO: optimize
@@ -109,15 +109,15 @@ end
 
 ## Gradient
 # Contains a vector of pre-allocated TPSs.
-struct GTPSAOneArgGradientPrep{SIG,X} <: DI.GradientPrep{SIG}
+struct GTPSAOneArgGradientPrep{SIG, X} <: DI.GradientPrep{SIG}
     _sig::Val{SIG}
     xt::X
 end
 
 # Unlike JVP, this requires us to use all variables
 function DI.prepare_gradient_nokwarg(
-    strict::Val, f, backend::AutoGTPSA{D}, x, contexts::Vararg{DI.Constant,C}
-) where {D,C}
+        strict::Val, f, backend::AutoGTPSA{D}, x, contexts::Vararg{DI.Constant, C}
+    ) where {D, C}
     _sig = DI.signature(f, backend, x, contexts...; strict)
     if D != Nothing
         d = backend.descriptor
@@ -127,7 +127,7 @@ function DI.prepare_gradient_nokwarg(
     xt = similar(x, TPS{promote_type(eltype(x), Float64)})
     j = 1
     for i in eachindex(xt)
-        xt[i] = TPS{promote_type(eltype(x), Float64)}(; use=d)
+        xt[i] = TPS{promote_type(eltype(x), Float64)}(; use = d)
         xt[i][j] = 1
         j += 1
     end
@@ -135,72 +135,72 @@ function DI.prepare_gradient_nokwarg(
 end
 
 function DI.gradient(
-    f, prep::GTPSAOneArgGradientPrep, backend::AutoGTPSA, x, contexts::Vararg{DI.Constant,C}
-) where {C}
+        f, prep::GTPSAOneArgGradientPrep, backend::AutoGTPSA, x, contexts::Vararg{DI.Constant, C}
+    ) where {C}
     DI.check_prep(f, prep, backend, x, contexts...)
     foreach((t, xi) -> t[0] = xi, prep.xt, x) # Set the scalar part (slopes set in prepare)
     fc = DI.fix_tail(f, map(DI.unwrap, contexts)...)
     yt = fc(prep.xt)
     grad = similar(x, GTPSA.numtype(yt))
-    GTPSA.gradient!(grad, yt; include_params=true, unsafe_inbounds=true)
+    GTPSA.gradient!(grad, yt; include_params = true, unsafe_inbounds = true)
     return grad
 end
 
 function DI.gradient!(
-    f,
-    grad,
-    prep::GTPSAOneArgGradientPrep,
-    backend::AutoGTPSA,
-    x,
-    contexts::Vararg{DI.Constant,C},
-) where {C}
+        f,
+        grad,
+        prep::GTPSAOneArgGradientPrep,
+        backend::AutoGTPSA,
+        x,
+        contexts::Vararg{DI.Constant, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, contexts...)
     foreach((t, xi) -> t[0] = xi, prep.xt, x) # Set the scalar part
     fc = DI.fix_tail(f, map(DI.unwrap, contexts)...)
     yt = fc(prep.xt)
-    GTPSA.gradient!(grad, yt; include_params=true, unsafe_inbounds=true)
+    GTPSA.gradient!(grad, yt; include_params = true, unsafe_inbounds = true)
     return grad
 end
 
 function DI.value_and_gradient(
-    f, prep::GTPSAOneArgGradientPrep, backend::AutoGTPSA, x, contexts::Vararg{DI.Constant,C}
-) where {C}
+        f, prep::GTPSAOneArgGradientPrep, backend::AutoGTPSA, x, contexts::Vararg{DI.Constant, C}
+    ) where {C}
     DI.check_prep(f, prep, backend, x, contexts...)
     foreach((t, xi) -> t[0] = xi, prep.xt, x) # Set the scalar part (slopes set in prepare)
     fc = DI.fix_tail(f, map(DI.unwrap, contexts)...)
     yt = fc(prep.xt)
     grad = similar(x, GTPSA.numtype(yt))
-    GTPSA.gradient!(grad, yt; include_params=true, unsafe_inbounds=true)
+    GTPSA.gradient!(grad, yt; include_params = true, unsafe_inbounds = true)
     return yt[0], grad
 end
 
 function DI.value_and_gradient!(
-    f,
-    grad,
-    prep::GTPSAOneArgGradientPrep,
-    backend::AutoGTPSA,
-    x,
-    contexts::Vararg{DI.Constant,C},
-) where {C}
+        f,
+        grad,
+        prep::GTPSAOneArgGradientPrep,
+        backend::AutoGTPSA,
+        x,
+        contexts::Vararg{DI.Constant, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, contexts...)
     foreach((t, xi) -> t[0] = xi, prep.xt, x) # Set the scalar part (slopes set in prepare)
     fc = DI.fix_tail(f, map(DI.unwrap, contexts)...)
     yt = fc(prep.xt)
-    GTPSA.gradient!(grad, yt; include_params=true, unsafe_inbounds=true)
+    GTPSA.gradient!(grad, yt; include_params = true, unsafe_inbounds = true)
     return yt[0], grad
 end
 
 ## Jacobian
 # Contains a vector of pre-allocated TPSs
-struct GTPSAOneArgJacobianPrep{SIG,X} <: DI.JacobianPrep{SIG}
+struct GTPSAOneArgJacobianPrep{SIG, X} <: DI.JacobianPrep{SIG}
     _sig::Val{SIG}
     xt::X
 end
 
 # To materialize the entire Jacobian we use all variables
 function DI.prepare_jacobian_nokwarg(
-    strict::Val, f, backend::AutoGTPSA{D}, x, contexts::Vararg{DI.Constant,C}
-) where {D,C}
+        strict::Val, f, backend::AutoGTPSA{D}, x, contexts::Vararg{DI.Constant, C}
+    ) where {D, C}
     _sig = DI.signature(f, backend, x, contexts...; strict)
     if D != Nothing
         d = backend.descriptor
@@ -212,7 +212,7 @@ function DI.prepare_jacobian_nokwarg(
     xt = similar(x, TPS{promote_type(eltype(x), Float64)})
     j = 1
     for i in eachindex(xt)
-        xt[i] = TPS{promote_type(eltype(x), Float64)}(; use=d)
+        xt[i] = TPS{promote_type(eltype(x), Float64)}(; use = d)
         xt[i][j] = 1
         j += 1
     end
@@ -220,91 +220,91 @@ function DI.prepare_jacobian_nokwarg(
 end
 
 function DI.jacobian(
-    f, prep::GTPSAOneArgJacobianPrep, backend::AutoGTPSA, x, contexts::Vararg{DI.Constant,C}
-) where {C}
+        f, prep::GTPSAOneArgJacobianPrep, backend::AutoGTPSA, x, contexts::Vararg{DI.Constant, C}
+    ) where {C}
     DI.check_prep(f, prep, backend, x, contexts...)
     foreach((t, xi) -> t[0] = xi, prep.xt, x) # Set the scalar part
     fc = DI.fix_tail(f, map(DI.unwrap, contexts)...)
     yt = fc(prep.xt)
     jac = similar(x, GTPSA.numtype(eltype(yt)), (length(yt), length(x)))
-    GTPSA.jacobian!(jac, yt; include_params=true, unsafe_inbounds=true)
+    GTPSA.jacobian!(jac, yt; include_params = true, unsafe_inbounds = true)
     return jac
 end
 
 function DI.jacobian!(
-    f,
-    jac,
-    prep::GTPSAOneArgJacobianPrep,
-    backend::AutoGTPSA,
-    x,
-    contexts::Vararg{DI.Constant,C},
-) where {C}
+        f,
+        jac,
+        prep::GTPSAOneArgJacobianPrep,
+        backend::AutoGTPSA,
+        x,
+        contexts::Vararg{DI.Constant, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, contexts...)
     foreach((t, xi) -> t[0] = xi, prep.xt, x) # Set the scalar part
     fc = DI.fix_tail(f, map(DI.unwrap, contexts)...)
     yt = fc(prep.xt)
-    GTPSA.jacobian!(jac, yt; include_params=true, unsafe_inbounds=true)
+    GTPSA.jacobian!(jac, yt; include_params = true, unsafe_inbounds = true)
     return jac
 end
 
 function DI.value_and_jacobian(
-    f, prep::GTPSAOneArgJacobianPrep, backend::AutoGTPSA, x, contexts::Vararg{DI.Constant,C}
-) where {C}
+        f, prep::GTPSAOneArgJacobianPrep, backend::AutoGTPSA, x, contexts::Vararg{DI.Constant, C}
+    ) where {C}
     DI.check_prep(f, prep, backend, x, contexts...)
     foreach((t, xi) -> t[0] = xi, prep.xt, x) # Set the scalar part
     fc = DI.fix_tail(f, map(DI.unwrap, contexts)...)
     yt = fc(prep.xt)
     jac = similar(x, GTPSA.numtype(eltype(yt)), (length(yt), length(x)))
-    GTPSA.jacobian!(jac, yt; include_params=true, unsafe_inbounds=true)
+    GTPSA.jacobian!(jac, yt; include_params = true, unsafe_inbounds = true)
     y = map(t -> t[0], yt)
     return y, jac
 end
 
 function DI.value_and_jacobian!(
-    f,
-    jac,
-    prep::GTPSAOneArgJacobianPrep,
-    backend::AutoGTPSA,
-    x,
-    contexts::Vararg{DI.Constant,C},
-) where {C}
+        f,
+        jac,
+        prep::GTPSAOneArgJacobianPrep,
+        backend::AutoGTPSA,
+        x,
+        contexts::Vararg{DI.Constant, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, contexts...)
     foreach((t, xi) -> t[0] = xi, prep.xt, x) # Set the scalar part
     fc = DI.fix_tail(f, map(DI.unwrap, contexts)...)
     yt = fc(prep.xt)
-    GTPSA.jacobian!(jac, yt; include_params=true, unsafe_inbounds=true)
+    GTPSA.jacobian!(jac, yt; include_params = true, unsafe_inbounds = true)
     y = map(t -> t[0], yt)
     return y, jac
 end
 
 ## Second derivative
 # Contains single pre-allocated TPS
-struct GTPSAOneArgSecondDerivativePrep{SIG,X} <: DI.SecondDerivativePrep{SIG}
+struct GTPSAOneArgSecondDerivativePrep{SIG, X} <: DI.SecondDerivativePrep{SIG}
     _sig::Val{SIG}
     xt::X
 end
 
 function DI.prepare_second_derivative_nokwarg(
-    strict::Val, f, backend::AutoGTPSA{D}, x, contexts::Vararg{DI.Constant,C}
-) where {D,C}
+        strict::Val, f, backend::AutoGTPSA{D}, x, contexts::Vararg{DI.Constant, C}
+    ) where {D, C}
     _sig = DI.signature(f, backend, x, contexts...; strict)
     if D != Nothing
         d = backend.descriptor
     else
         d = Descriptor(1, 2)
     end
-    xt = TPS{promote_type(typeof(x), Float64)}(; use=d)
+    xt = TPS{promote_type(typeof(x), Float64)}(; use = d)
     xt[1] = 1 # Set slope
     return GTPSAOneArgSecondDerivativePrep(_sig, xt)
 end
 
 function DI.second_derivative(
-    f,
-    prep::GTPSAOneArgSecondDerivativePrep,
-    backend::AutoGTPSA{D},
-    x,
-    contexts::Vararg{DI.Constant,C},
-) where {D,C}
+        f,
+        prep::GTPSAOneArgSecondDerivativePrep,
+        backend::AutoGTPSA{D},
+        x,
+        contexts::Vararg{DI.Constant, C},
+    ) where {D, C}
     DI.check_prep(f, prep, backend, x, contexts...)
     prep.xt[0] = x
     fc = DI.fix_tail(f, map(DI.unwrap, contexts)...)
@@ -327,13 +327,13 @@ function DI.second_derivative(
 end
 
 function DI.second_derivative!(
-    f,
-    der2,
-    prep::GTPSAOneArgSecondDerivativePrep,
-    backend::AutoGTPSA{D},
-    x,
-    contexts::Vararg{DI.Constant,C},
-) where {D,C}
+        f,
+        der2,
+        prep::GTPSAOneArgSecondDerivativePrep,
+        backend::AutoGTPSA{D},
+        x,
+        contexts::Vararg{DI.Constant, C},
+    ) where {D, C}
     DI.check_prep(f, prep, backend, x, contexts...)
     prep.xt[0] = x
     fc = DI.fix_tail(f, map(DI.unwrap, contexts)...)
@@ -350,12 +350,12 @@ function DI.second_derivative!(
 end
 
 function DI.value_derivative_and_second_derivative(
-    f,
-    prep::GTPSAOneArgSecondDerivativePrep,
-    backend::AutoGTPSA{D},
-    x,
-    contexts::Vararg{DI.Constant,C},
-) where {D,C}
+        f,
+        prep::GTPSAOneArgSecondDerivativePrep,
+        backend::AutoGTPSA{D},
+        x,
+        contexts::Vararg{DI.Constant, C},
+    ) where {D, C}
     DI.check_prep(f, prep, backend, x, contexts...)
     prep.xt[0] = x
     fc = DI.fix_tail(f, map(DI.unwrap, contexts)...)
@@ -380,14 +380,14 @@ function DI.value_derivative_and_second_derivative(
 end
 
 function DI.value_derivative_and_second_derivative!(
-    f,
-    der,
-    der2,
-    prep::GTPSAOneArgSecondDerivativePrep,
-    backend::AutoGTPSA{D},
-    x,
-    contexts::Vararg{DI.Constant,C},
-) where {D,C}
+        f,
+        der,
+        der2,
+        prep::GTPSAOneArgSecondDerivativePrep,
+        backend::AutoGTPSA{D},
+        x,
+        contexts::Vararg{DI.Constant, C},
+    ) where {D, C}
     DI.check_prep(f, prep, backend, x, contexts...)
     prep.xt[0] = x
     fc = DI.fix_tail(f, map(DI.unwrap, contexts)...)
@@ -408,15 +408,15 @@ end
 ## Hessian
 # Stores allocated array of TPS and an array for the monomial coefficient
 # indexing in GTPSA.cycle! (which is used if a Descriptor is specified)
-struct GTPSAOneArgHessianPrep{SIG,X,M} <: DI.HessianPrep{SIG}
+struct GTPSAOneArgHessianPrep{SIG, X, M} <: DI.HessianPrep{SIG}
     _sig::Val{SIG}
     xt::X
     m::M
 end
 
 function DI.prepare_hessian_nokwarg(
-    strict::Val, f, backend::AutoGTPSA{D}, x, contexts::Vararg{DI.Constant,C}
-) where {D,C}
+        strict::Val, f, backend::AutoGTPSA{D}, x, contexts::Vararg{DI.Constant, C}
+    ) where {D, C}
     _sig = DI.signature(f, backend, x, contexts...; strict)
     if D != Nothing
         d = backend.descriptor
@@ -435,7 +435,7 @@ function DI.prepare_hessian_nokwarg(
     # linear with the variables.
     j = 1
     for i in eachindex(xt)
-        xt[i] = TPS{promote_type(eltype(x), Float64)}(; use=d)
+        xt[i] = TPS{promote_type(eltype(x), Float64)}(; use = d)
         xt[i][j] = 1
         j += 1
     end
@@ -444,12 +444,12 @@ function DI.prepare_hessian_nokwarg(
 end
 
 function DI.hessian(
-    f,
-    prep::GTPSAOneArgHessianPrep,
-    backend::AutoGTPSA{D},
-    x,
-    contexts::Vararg{DI.Constant,C},
-) where {D,C}
+        f,
+        prep::GTPSAOneArgHessianPrep,
+        backend::AutoGTPSA{D},
+        x,
+        contexts::Vararg{DI.Constant, C},
+    ) where {D, C}
     DI.check_prep(f, prep, backend, x, contexts...)
     foreach((t, xi) -> t[0] = xi, prep.xt, x) # Set the scalar part
     fc = DI.fix_tail(f, map(DI.unwrap, contexts)...)
@@ -459,22 +459,22 @@ function DI.hessian(
     GTPSA.hessian!(
         hess,
         yt;
-        include_params=true,
-        unsafe_inbounds=true,
-        unsafe_fast=unsafe_fast,
-        tmp_mono=prep.m,
+        include_params = true,
+        unsafe_inbounds = true,
+        unsafe_fast = unsafe_fast,
+        tmp_mono = prep.m,
     )
     return hess
 end
 
 function DI.hessian!(
-    f,
-    hess,
-    prep::GTPSAOneArgHessianPrep,
-    backend::AutoGTPSA{D},
-    x,
-    contexts::Vararg{DI.Constant,C},
-) where {D,C}
+        f,
+        hess,
+        prep::GTPSAOneArgHessianPrep,
+        backend::AutoGTPSA{D},
+        x,
+        contexts::Vararg{DI.Constant, C},
+    ) where {D, C}
     DI.check_prep(f, prep, backend, x, contexts...)
     foreach((t, xi) -> t[0] = xi, prep.xt, x) # Set the scalar part
     fc = DI.fix_tail(f, map(DI.unwrap, contexts)...)
@@ -483,75 +483,75 @@ function DI.hessian!(
     GTPSA.hessian!(
         hess,
         yt;
-        include_params=true,
-        unsafe_inbounds=true,
-        unsafe_fast=unsafe_fast,
-        tmp_mono=prep.m,
+        include_params = true,
+        unsafe_inbounds = true,
+        unsafe_fast = unsafe_fast,
+        tmp_mono = prep.m,
     )
     return hess
 end
 
 function DI.value_gradient_and_hessian(
-    f,
-    prep::GTPSAOneArgHessianPrep,
-    backend::AutoGTPSA{D},
-    x,
-    contexts::Vararg{DI.Constant,C},
-) where {D,C}
+        f,
+        prep::GTPSAOneArgHessianPrep,
+        backend::AutoGTPSA{D},
+        x,
+        contexts::Vararg{DI.Constant, C},
+    ) where {D, C}
     DI.check_prep(f, prep, backend, x, contexts...)
     foreach((t, xi) -> t[0] = xi, prep.xt, x) # Set the scalar part
     fc = DI.fix_tail(f, map(DI.unwrap, contexts)...)
     yt = fc(prep.xt)
     grad = similar(x, GTPSA.numtype(yt))
-    GTPSA.gradient!(grad, yt; include_params=true, unsafe_inbounds=true)
+    GTPSA.gradient!(grad, yt; include_params = true, unsafe_inbounds = true)
     hess = similar(x, GTPSA.numtype(yt), (length(x), length(x)))
     unsafe_fast = D == Nothing ? true : false
     GTPSA.hessian!(
         hess,
         yt;
-        include_params=true,
-        unsafe_inbounds=true,
-        unsafe_fast=unsafe_fast,
-        tmp_mono=prep.m,
+        include_params = true,
+        unsafe_inbounds = true,
+        unsafe_fast = unsafe_fast,
+        tmp_mono = prep.m,
     )
     return yt[0], grad, hess
 end
 
 function DI.value_gradient_and_hessian!(
-    f,
-    grad,
-    hess,
-    prep::GTPSAOneArgHessianPrep,
-    backend::AutoGTPSA{D},
-    x,
-    contexts::Vararg{DI.Constant,C},
-) where {D,C}
+        f,
+        grad,
+        hess,
+        prep::GTPSAOneArgHessianPrep,
+        backend::AutoGTPSA{D},
+        x,
+        contexts::Vararg{DI.Constant, C},
+    ) where {D, C}
     DI.check_prep(f, prep, backend, x, contexts...)
     foreach((t, xi) -> t[0] = xi, prep.xt, x) # Set the scalar part
     fc = DI.fix_tail(f, map(DI.unwrap, contexts)...)
     yt = fc(prep.xt)
-    GTPSA.gradient!(grad, yt; include_params=true, unsafe_inbounds=true)
+    GTPSA.gradient!(grad, yt; include_params = true, unsafe_inbounds = true)
     unsafe_fast = D == Nothing ? true : false
     GTPSA.hessian!(
         hess,
         yt;
-        include_params=true,
-        unsafe_inbounds=true,
-        unsafe_fast=unsafe_fast,
-        tmp_mono=prep.m,
+        include_params = true,
+        unsafe_inbounds = true,
+        unsafe_fast = unsafe_fast,
+        tmp_mono = prep.m,
     )
     return yt[0], grad, hess
 end
 
-struct GTPSAOneArgHVPPrep{SIG,E,H} <: DI.HVPPrep{SIG}
+struct GTPSAOneArgHVPPrep{SIG, E, H} <: DI.HVPPrep{SIG}
     _sig::Val{SIG}
     hessprep::E
     hess::H
 end
 
 function DI.prepare_hvp_nokwarg(
-    strict::Val, f, backend::AutoGTPSA, x, tx::NTuple, contexts::Vararg{DI.Constant,C}
-) where {C}
+        strict::Val, f, backend::AutoGTPSA, x, tx::NTuple, contexts::Vararg{DI.Constant, C}
+    ) where {C}
     _sig = DI.signature(f, backend, x, tx, contexts...; strict)
     hessprep = DI.prepare_hessian_nokwarg(strict, f, backend, x, contexts...)
     fc = DI.fix_tail(f, map(DI.unwrap, contexts)...)
@@ -560,13 +560,13 @@ function DI.prepare_hvp_nokwarg(
 end
 
 function DI.hvp(
-    f,
-    prep::GTPSAOneArgHVPPrep,
-    backend::AutoGTPSA,
-    x,
-    tx::NTuple,
-    contexts::Vararg{DI.Constant,C},
-) where {C}
+        f,
+        prep::GTPSAOneArgHVPPrep,
+        backend::AutoGTPSA,
+        x,
+        tx::NTuple,
+        contexts::Vararg{DI.Constant, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, tx, contexts...)
     DI.hessian!(f, prep.hess, prep.hessprep, backend, x, contexts...)
     tg = map(tx) do dx
@@ -585,14 +585,14 @@ function DI.hvp(
 end
 
 function DI.hvp!(
-    f,
-    tg::NTuple,
-    prep::GTPSAOneArgHVPPrep,
-    backend::AutoGTPSA,
-    x,
-    tx::NTuple,
-    contexts::Vararg{DI.Constant,C},
-) where {C}
+        f,
+        tg::NTuple,
+        prep::GTPSAOneArgHVPPrep,
+        backend::AutoGTPSA,
+        x,
+        tx::NTuple,
+        contexts::Vararg{DI.Constant, C},
+    ) where {C}
     DI.check_prep(f, prep, backend, x, tx, contexts...)
     DI.hessian!(f, prep.hess, prep.hessprep, backend, x, contexts...)
     for b in eachindex(tg)
@@ -610,13 +610,13 @@ function DI.hvp!(
 end
 
 function DI.gradient_and_hvp(
-    f,
-    prep::GTPSAOneArgHVPPrep,
-    backend::AutoGTPSA{D},
-    x,
-    tx::NTuple,
-    contexts::Vararg{DI.Constant,C},
-) where {D,C}
+        f,
+        prep::GTPSAOneArgHVPPrep,
+        backend::AutoGTPSA{D},
+        x,
+        tx::NTuple,
+        contexts::Vararg{DI.Constant, C},
+    ) where {D, C}
     DI.check_prep(f, prep, backend, x, tx, contexts...)
     grad = similar(x, eltype(prep.hess))
     DI.value_gradient_and_hessian!(
@@ -638,15 +638,15 @@ function DI.gradient_and_hvp(
 end
 
 function DI.gradient_and_hvp!(
-    f,
-    grad,
-    tg,
-    prep::GTPSAOneArgHVPPrep,
-    backend::AutoGTPSA{D},
-    x,
-    tx::NTuple,
-    contexts::Vararg{DI.Constant,C},
-) where {D,C}
+        f,
+        grad,
+        tg,
+        prep::GTPSAOneArgHVPPrep,
+        backend::AutoGTPSA{D},
+        x,
+        tx::NTuple,
+        contexts::Vararg{DI.Constant, C},
+    ) where {D, C}
     DI.check_prep(f, prep, backend, x, tx, contexts...)
     DI.value_gradient_and_hessian!(
         f, grad, prep.hess, prep.hessprep, backend, x, contexts...
