@@ -1,9 +1,11 @@
 ## Pushforward
 
-struct MooncakeOneArgPushforwardPrep{SIG, Tcache, DX} <: DI.PushforwardPrep{SIG}
+struct MooncakeOneArgPushforwardPrep{SIG, Tcache, DX, FT, CT} <: DI.PushforwardPrep{SIG}
     _sig::Val{SIG}
     cache::Tcache
     dx_righttype::DX
+    df::FT
+    context_tangents::CT
 end
 
 function DI.prepare_pushforward_nokwarg(
@@ -20,7 +22,9 @@ function DI.prepare_pushforward_nokwarg(
         f, x, map(DI.unwrap, contexts)...; config.debug_mode, config.silence_debug_messages
     )
     dx_righttype = zero_tangent(x)
-    prep = MooncakeOneArgPushforwardPrep(_sig, cache, dx_righttype)
+    df = zero_tangent(f)
+    context_tangents = map(zero_tangent_unwrap, contexts)
+    prep = MooncakeOneArgPushforwardPrep(_sig, cache, dx_righttype, df, context_tangents)
     return prep
 end
 
@@ -38,9 +42,9 @@ function DI.value_and_pushforward(
             dx isa tangent_type(X) ? dx : _copy_to_output!!(prep.dx_righttype, dx)
         y_dual = value_and_derivative!!(
             prep.cache,
-            zero_dual(f),
+            Dual(f, prep.df),
             Dual(x, dx_righttype),
-            map(zero_dual ∘ DI.unwrap, contexts)...,
+            map(Dual_unwrap, contexts, prep.context_tangents)...,
         )
         y = primal(y_dual)
         dy = _copy_output(tangent(y_dual))
