@@ -1,7 +1,4 @@
-# see https://github.com/JuliaDiff/DifferentiationInterface.jl/issues/855
-
-using Pkg
-Pkg.add("Enzyme")
+include("../../testutils.jl")
 
 using ADTypes: ADTypes
 using DifferentiationInterface, DifferentiationInterfaceTest
@@ -14,8 +11,6 @@ using Test
 using ExplicitImports
 check_no_implicit_imports(DifferentiationInterface)
 
-LOGGING = get(ENV, "CI", "false") == "false"
-
 backends = [
     AutoEnzyme(; mode = nothing),
     AutoEnzyme(; mode = Enzyme.Forward),
