@@ -1,5 +1,4 @@
 using Pkg
-Pkg.add("FiniteDiff")
 
 using ADTypes: ADTypes
 using DifferentiationInterface, DifferentiationInterfaceTest
@@ -8,8 +7,6 @@ import DifferentiationInterfaceTest as DIT
 using FiniteDiff: FiniteDiff
 using Test
 
-LOGGING = get(ENV, "CI", "false") == "false"
-
 @testset "Benchmarking sparse" begin
     filtered_sparse_scenarios = filter(sparse_scenarios(; band_sizes = [])) do scen
         DIT.function_place(scen) == :in &&
