@@ -1,7 +1,19 @@
+using Pkg
+
+@static if VERSION < v"1.11"
+    DIT_PATH = joinpath(@__DIR__, "..", "..", "DifferentiationInterfaceTest")
+    if isdir(DIT_PATH)
+        Pkg.develop(; path = DIT_PATH)
+    else
+        Pkg.add("DifferentiationInterfaceTest")
+    end
+end
+
 using ADTypes
 using DifferentiationInterfaceTest
 using SparseConnectivityTracer
 using SparseMatrixColorings
+using Test
 
 using DifferentiationInterfaceTest:
     default_scenarios,
@@ -22,3 +34,5 @@ function MyAutoSparse(backend::AbstractADType)
 end
 
 safetypestab(symb) = VERSION < v"1.12-" ? symb : :none  # TODO: remove
+
+LOGGING = get(ENV, "CI", "false") == "false"
